#
# spec file for package python-zeroconf
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-zeroconf
Version:        0.25.1
Release:        bp156.3.2
Summary:        Pure Python Multicast DNS Service Discovery Library (Bonjour/Avahi compatible)
License:        LGPL-2.0-only
Group:          Development/Languages/Python
URL:            https://github.com/jstasiak/python-zeroconf
Source:         https://github.com/jstasiak/python-zeroconf/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module ifaddr}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ifaddr
BuildArch:      noarch
%python_subpackages

%description
This is a fork of pyzeroconf, a Multicast DNS Service Discovery for Python.
It is compatible with Bonjour and Avahi.
Compared to some other Zeroconf/Bonjour/Avahi Python packages, python-zeroconf
is not tied to Bonjour or Avahi, does not use D-Bus and
does not force you to use a particular event loop or python-twisted.

%prep
%setup -q

%build
%python_build

%install
%python_install
%python_expand rm -f %{buildroot}%{$python_sitelib}/zeroconf/test.py
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest zeroconf/test.py -k 'not (test_integration_with_listener_ipv6 or test_launch)'

%files %{python_files}
%doc README.rst
%license COPYING
%{python_sitelib}/zeroconf*

%changelog
* Thu Apr 16 2020 pgajdos@suse.com
- version update to 0.25.1
  * Eliminated 5s hangup when calling Zeroconf.close(), thanks to Erik Montnemery
  * Reverted uniqueness assertions when browsing, they caused a regression
  Backwards incompatible:
  * Rationalized handling of TXT records.
- deleted patches
  - python-zeroconf-disable-some-tests.patch (not needed, replaced by -k 'not ...')
* Mon Mar  9 2020 pgajdos@suse.com
- version update to 0.24.5
  * Fixed issues with shared records being used where they shouldn't be (TXT, SRV, A records are
    unique now), thanks to Matt Saxon
  * Stopped unnecessarily excluding host-only interfaces from InterfaceChoice.all as they don't
    forbid multicast, thanks to Andreas Oberritter
  * Fixed repr() of IPv6 DNSAddress, thanks to Aldo Hoeben
  * Removed duplicate update messages sent to listeners, thanks to Matt Saxon
  * Added support for cooperating responders, thanks to Matt Saxon
  * Optimized handle_response cache check, thanks to J. Nick Koston
  * Fixed memory leak in DNSCache, thanks to J. Nick Koston
  * Fixed resetting TTL in DNSRecord.reset_ttl(), thanks to Matt Saxon
  * Improved various DNS class' string representations, thanks to Jay Hogg
* Sat Dec 28 2019 Martin Hauke <mardnh@gmx.de>
- Adjust dependencies and the %%check section so the testsuite can
  still be executed
- Add patch:
  * python-zeroconf-disable-some-tests.patch
- Update to version 0.24.3
  * Fixed import-time "TypeError: 'ellipsis' object is not
    iterable." on CPython 3.5.2
- Update to version 0.24.2
  * Added support for AWDL interface on macOS (needed and used by
    the opendrop project but should be useful in general)
  * Added missing type hints
- Update to version 0.24.1
  * Applied some significant performance optimizations
  * Fixed flushing outdated cache entries when incoming record
    is unique
  * Fixed handling updates of TXT records (they'd not get recorded
    previously)
- Update to version 0.24.0
  * Added IPv6 support
  * Added additional recommended records to PTR responses
  * Added handling of ENOTCONN being raised during shutdown when
    using Eventlet
  * Included the py.typed marker in the package so that type
    checkers know to use type hints from the source code
* Thu Jun  6 2019 Adrian Schröter <adrian@suse.de>
- version update to 0.23.0
  * support for python 3.4 got dropped
  * Add support for MyListener call getting updates to service TXT record
  * Add support for multiple addresses when publishing a service
* Mon May  6 2019 pgajdos@suse.com
- version update to 0.22.0
  * A lot of maintenance work (tooling, typing coverage and improvements,
    spelling)
  * Provided saner defaults in ServiceInfo's constructor, thanks to
    Jorge Miranda
  * Fixed service removal packets not being sent on shutdown, thanks to
    Andrew Bonney
  * Added a way to define TTL-s through ServiceInfo contructor parameters,
    thanks to Andrew Bonney
  * Adjusted query intervals to match RFC 6762, thanks to Andrew Bonney
  * Made default TTL-s match RFC 6762, thanks to Andrew Bonney
* Mon Mar 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.21.3:
  * no upstream changelog
  * dropped python2 support
- Execute tests
- Update requirements based on upstream requires
* Thu Feb 15 2018 alarrosa@suse.com
- Remove patch which was breaking zeroconf dependency check with python3
  (it was making pkg_resources generate a DistributionNotFound exception
  because enum34 wasn't found). enum34 is only required by the python2
  package, which is what the enum-compat  package is all about.
  * python-zeroconf-0.19.1-enum34-instead-of-enum-compat.patch
- Require python-enum-compat to require python-enum34 on python2 and
  nothing on python3, just as the egg's requires.txt file does.
* Fri Jul  7 2017 antoine.belvire@opensuse.org
- Update to version 0.19.1:
  * Remove outdated example
  * On Windows, python-netifaces 0.10.5 triggers a bug - This has
    no impact for us, therefore there is no need for us to add a
    version requirement on this dependency as upstream did.
- Rebase patch:
  * Remove
    python-zeroconf-0.17.4-enum34-instead-of-enum-compat.patch.
  * Add python-zeroconf-0.19.1-enum34-instead-of-enum-compat.patch.
* Sat Mar 18 2017 antoine.belvire@opensuse.org
- Remove .changes file from source (not needed).
* Sat Mar 18 2017 stefan.bruens@rwth-aachen.de
- Convert package to python singlespec
* Sat Feb 18 2017 antoine.belvire@opensuse.org
- Update to 0.18.0:
  * Dropped Python 2.6 support
  * Improved error handling inside code executed when Zeroconf
    object is being closed
- Changes from 0.17.7:
  * Better Handling of DNS Incoming Packets parsing exceptions
  * Many exceptions will now log a warning the first time they are seen
  * Catch and log sendto() errors
  * Fix/Implement duplicate name change
  * Fix overly strict name validation introduced in 0.17.6
  * Greatly improve handling of oversized packets including:
    + Implement name compression per RFC1035
    + Limit size of generated packets to 9000 bytes as per RFC6762
    + Better handle over sized incoming packets
  * Increased test coverage to 95%%
* Wed Dec 28 2016 jengelh@inai.de
- Improve write style of description
* Wed Dec 28 2016 tbechtold@suse.com
- Use pypi.io as Source
* Sun Jul 17 2016 antoine.belvire@laposte.net
- Update to 0.17.6:
  * Many improvements to address race conditions and exceptions
    during ZC() startup and shutdown, thanks to: morpav, veawor,
    justingiorgi, herczy, stephenrauch
  * Added more test coverage: strahlex, stephenrauch
  * Stephen Rauch contributed:
    + Speed up browser startup
    + Add ZeroconfServiceTypes() query class to discover all
    advertised service types
    + Add full validation for service names, types and subtypes
    + Fix for subtype browsing
    + Fix DNSHInfo support
* Wed Mar 16 2016 antoine.belvire@laposte.net
- Fix build on SLE 11: avoid BuildArch noarch.
* Wed Mar 16 2016 antoine.belvire@laposte.net
- Update to 0.17.5:
  * Fix OpenBSD compatibility, thanks to Alessio Sergi
  * Fix race condition on ServiceBrowser startup, thanks to
    gbiddison
  * Fix installation on some Python 3 systems, thanks to Per
    Sandström
  * Fixed "size change during iteration" bug on Python 3, thanks to
    gbiddison
* Thu Mar 10 2016 antoine.belvire@laposte.net
- New package: python-zeroconf-0.17.4
- Add python-zeroconf-0.17.4-enum34-instead-of-enum-compat.patch:
  there is no need for a virtual python-enum-compat package here.
